#!/usr/bin/env zsh
source "${HOME}/.zshrc"

echo "<html><body>"


echo "<style>"
echo "pre {"
echo "font-family: Consolas, Courier, monospace;"
echo "white-space: pre-wrap;"
echo "tab-size: 4;"
echo "background: #D3D3D3;"
echo "color: black;"
echo "padding:20px;"
echo "border-radius: 5px;"
echo "}"
echo "</style>"

echo "<img src=\"icon.png\" style=\"float: right;\">"

# Check for Alfred being installed - it really should be if they are running this script
# But for completeness and in case I have to ask someone to run it standalone.
echo "<h1>Alfred</h1>"
if [ -d "/Applications/Alfred 4.app" ]
then
	echo "<p style=\"color:green\">&check; Alfred 4 is installed.</p>"
else
	echo "<p style=\"color:red\">&cross; We cannot find an installation of the Alfred 4 app.</p>"
	echo "<p>Please install <a href=\"https://www.alfredapp.com\">the Alfred app from Alfred App's website</a>.</p>"
fi

echo "<p>The generator for this page is a custom Alfred workflow. To run it, you <strong>must</strong> have a valid <a href=\"https://www.alfredapp.com/powerpack/\">Alfred Power Pack license</a> in place.</p>"

cd "$HOME/Library/Application Support/Alfred"
alfredLicenseFile=$(ls license.*.plist) 2>/dev/null
if [ "$alfredLicenseFile" = "" ]
then
	echo "<p style=\"color:red\">&cross; We cannot find the Alfred Power Pack license information.</p>"
else
	echo "<p style=\"color:green\">&check; Alfred 4 Power Pack information identified.</p>"
	licensePath=$(ls license.*.plist)	
	licenseEmail=$(defaults read "$HOME/Library/Application Support/Alfred/$licensePath" email)
	licenseCode=$(defaults read "$HOME/Library/Application Support/Alfred/$licensePath" code)
	
	echo "<details>"
	echo "<summary>Alfred Power Pack Information</summary>"
	echo "<div><ul>"
	echo "	<li>License E-mail: $licenseEmail</li>"
	echo "	<li>License Code: $licenseCode</li>"
	echo "</ul></div>"
	echo "</details>"
fi

# Gather Python 3 information for the Alfred session
p3=$(python3 --version)
pd=$(python --version)

# Output Python 3 Information
echo "<h1>Python 3</h1>"
echo "<p>To make use of Python 3, it must be installed and be found in your \$PATH environment variable, so that Conductor knows where to find it.</p>"
echo
echo "<p>We found the following Python 3 information:</p>"
echo 
echo "<ul>"
echo "<li>Python 3: $p3</li>"
echo "<li>Python (Default): $pd</li>"
echo "</ul>"
echo

# Check the length of the Python 3 version string
if [[ -n "$p3" ]]
then
	echo "<p style=\"color:green\">&check; Alfred can find a Python 3 installation.</p>"
else
	echo "<p style=\"color:red\">&cross; Alfred cannot find a Python 3 installation.</p>"
	echo "<p>Please read <a href=\"https://doctordrafts.thoughtasylum.com/basic/installation/\">how to install Python 3 for use with Doctor Drafts (another Alfred workflow by Stephen Millard) - the same Python installation instructions should work for Conductor too</a>.</p>"
fi

echo
echo "<h1>PATH Variable</h1>"
echo "<p>Your \$PATH variable paths are as follows:</p>"
echo
echo "<pre>"
# Substitute the path delimiters with newlines
echo -e ${PATH:gs/\:/\\n/}
echo "</pre>"

echo
echo "<h1>Personal Python Configuration</h1>"

echo
echo "<h2>.zshenv Content</h2>"
echo "<p>Your ZSH Environment file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zshenv"
echo "</pre>"

echo
echo "<h2>.zprofile Content</h2>"
echo "<p>Your ZSH Profile file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zprofile"
echo "</pre>"

echo
echo "<h2>.zshrc Content</h2>"
echo "<p>Your ZSH Run Command file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zshrc"
echo "</pre>"

echo
echo "<h2>.zlogin Content</h2>"
echo "<p>Your ZSH login file content is as follows:</p>"
echo
echo "<pre>"
cat "$HOME/.zlogin"
echo "</pre>"


echo 
echo "<h1>All Users Python Configuration</h1>"

echo
echo "<h2>/etc/zshenv Content</h2>"
echo "<p>Your ZSH Environment file content is as follows:</p>"
echo
echo "<pre>"
cat "/etc/zshenv"
echo "</pre>"

echo
echo "<h2>/etc/zprofile Content</h2>"
echo "<p>Your ZSH Profile file content is as follows:</p>"
echo
echo "<pre>"
cat "/etc/zprofile"
echo "</pre>"

echo
echo "<h2>/etc/zshrc Content</h2>"
echo "<p>Your ZSH Run Command file content is as follows:</p>"
echo
echo "<pre>"
cat "/etc/zshrc"
echo "</pre>"

echo
echo "<h2>/etc/zlogin Content</h2>"
echo "<p>Your ZSH login file content is as follows:</p>"
echo
echo "<pre>"
cat "/etc/zlogin"
echo "</pre>"


echo
echo "<hr><p>Last Generated: $(date) by &copy; Python Test from <a href=\"https://thoughtasylum.com\">ThoughtAsylum</a>.</p><hr>"
echo "</body></html>"